@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
 # Getting Things GNOME! - a personal organizer for the GNOME desktop
 # Copyright (c) 2008-2013 - Lionel Dricot & Bertrand Rousseau
@@ -19,12 +18,13 @@
 
 import os
 import pickle
-from xdg.BaseDirectory import xdg_config_home
+import logging
+from GTG.core.dirs import plugin_configuration_dir
 
-from GTG.tools.logger import Log
+log = logging.getLogger(__name__)
 
 
-class PluginAPI:
+class PluginAPI():
     """The plugin engine's API.
 
     L{PluginAPI} is a object that provides a nice API for
@@ -53,12 +53,10 @@ class PluginAPI:
         if taskeditor:
             self.__ui = taskeditor
             self.__builder = self.__ui.get_builder()
-            self.__toolbar = self.__builder.get_object('task_tb1')
             self.__task_id = taskeditor.get_task()
         else:
-            self.__ui = self.__view_manager.get_browser()
+            self.__ui = self.__view_manager.browser
             self.__builder = self.__ui.get_builder()
-            self.__toolbar = self.__builder.get_object('task_toolbar')
             self.__task_id = None
             self.__view_manager.browser.selection.connect(
                 "changed", self.__selection_changed)
@@ -69,7 +67,7 @@ class PluginAPI:
         for func in self.selection_changed_callback_listeners:
             func(selection)
 
-#=== Accessor methods ========================================================
+# Accessor methods ============================================================
     def is_editor(self):
         """
         Returns true if this is an Editor API
@@ -101,15 +99,35 @@ class PluginAPI:
         return self.__builder
 
     def get_ui(self):
-        '''
+        """
         Returns a Browser or an Editor
-        '''
+        """
         return self.__ui
 
+    def get_browser(self):
+        """
+        Returns a Browser
+        """
+        return self.__view_manager.browser
+
+    def get_menu(self):
+        """
+        Return the menu entry to the menu of the Task Browser or Task Editor.
+        """
+        return self.__builder.get_object('main_menu')
+
+    def get_header(self):
+        """Return the headerbar of the mainwindow"""
+        return self.__builder.get_object('browser_headerbar')
+
+    def get_quickadd_pane(self):
+        """Return the quickadd pane"""
+        return self.__builder.get_object('quickadd_pane')
+
     def get_selected(self):
-        '''
+        """
         Returns the selected tasks in the browser or the task ID if the editor
-        '''
+        """
         if self.is_editor():
             return self.__task_id
         else:
@@ -121,64 +139,37 @@ class PluginAPI:
 
     def remove_active_selection_changed_callback(self, plugin_class):
         new_list = [func for func in self.selection_changed_callback_listeners
-                    if func.im_class != plugin_class]
+                    if func.__class__ != plugin_class]
         self.selection_changed_callback_listeners = new_list
 
-#=== Changing the UI =========================================================
+# Changing the UI ===========================================================
     def add_menu_item(self, item):
-        """Adds a menu entry to the Plugin Menu of the Main Window
-        (task browser).
+        """Adds a menu entry to the menu of the Task Browser or Task Editor.
 
-        @param item: The gtk.MenuItem that is going to be added.
+        @param item: The Gtk.MenuItem that is going to be added.
         """
-        widget = self.__builder.get_object('plugin_mi')
-        widget.get_submenu().append(item)
-        widget.show_all()
+        menu_box = self.__builder.get_object('menu_box')
+        menu_box.add(item)
+        menu_box.reorder_child(item, 1)
+        menu_box.show_all()
 
     def remove_menu_item(self, item):
-        """Removes a menu entry from the Plugin Menu of the Main Window
-        (task browser).
+        """Remove a menu entry to the menu of the Task Browser or Task Editor.
 
-        @param item: The gtk.MenuItem that is going to be removed.
-        @return: Returns C{True} if the operation has sucess or c{False} if it
-        fails.
+        @param item: The Gtk.MenuItem that is going to be removed.
         """
-        menu = self.__builder.get_object('plugin_mi')
-        submenu = menu.get_submenu()
-        try:
-            submenu.remove(item)
-        except:
-            pass
-        if not submenu.get_children():
-                menu.hide()
 
-    def add_toolbar_item(self, widget):
-        """Adds a button to the task browser's toolbar or the task editor
-        toolbar, depending on which plugin api it's being used.
-
-        @param widget: The gtk.ToolButton that is going to be added to the
-        toolbar.
-        """
-        #-1 means "append to the end"
-        self.__toolbar.insert(widget, -1)
-
-    def remove_toolbar_item(self, widget):
-        """
-        Remove a widget from the toolbar.
-        """
-        try:
-            self.__toolbar.remove(widget)
-        except Exception, e:
-            print "Error removing the toolbar item in the TaskEditor: %s" % e
+        menu_box = self.__builder.get_object('menu_box')
+        menu_box.remove(item)
 
     def add_widget_to_taskeditor(self, widget):
         """Adds a widget to the bottom of the task editor dialog
 
-        @param widget: The gtk.Widget that is going to be added.
+        @param widget: The Gtk.Widget that is going to be added.
         """
-        vbox = self.__builder.get_object('vbox4')
+        vbox = self.__builder.get_object('pluginbox')
         if vbox:
-            vbox.pack_start(widget)
+            vbox.add(widget)
             vbox.reorder_child(widget, -2)
             widget.show_all()
             self.taskwidget_id += 1
@@ -190,16 +181,16 @@ class PluginAPI:
     def remove_widget_from_taskeditor(self, widg_id):
         """Remove a widget from the bottom of the task editor dialog
 
-        @param widget: The gtk.Widget that is going to be removed
+        @param widget: The Gtk.Widget that is going to be removed
         """
         if self.is_editor() and widg_id:
             try:
                 wi = self.__builder.get_object('vbox4')
                 if wi and widg_id in self.taskwidget_widg:
                     wi.remove(self.taskwidget_widg.pop(widg_id))
-            except Exception, e:
-                Log.debug("Error removing the toolbar item in the TaskEditor:"
-                          "%s" % e)
+            except Exception:
+                log.exception("Error removing the toolbar item in the "
+                              "TaskEditor:")
 
     def set_bgcolor_func(self, func=None):
         """ Set a function which defines a background color for each task
@@ -207,42 +198,38 @@ class PluginAPI:
         NOTE: This function stronglye depend on browser and could be easily
         broken by changes in browser code
         """
-        browser = self.__ui
+        browser = self.get_browser()
 
         # set default bgcolor?
         if func is None:
-            func = browser.tv_factory.task_bg_color
+            func = browser.tv_factory.get_task_bg_color
 
-        for pane in browser.vtree_panes.itervalues():
+        for pane in browser.vtree_panes.values():
             pane.set_bg_color(func, 'bg_color')
             pane.basetree.get_basetree().refresh_all()
 
-#=== file saving/loading =====================================================
+# file saving/loading =======================================================
     def load_configuration_object(self, plugin_name, filename,
-                                  basedir=xdg_config_home,
                                   default_values=None):
         if default_values is not None:
             config = dict(default_values)
         else:
             config = dict()
 
-        dirname = os.path.join(basedir, 'gtg/plugins', plugin_name)
+        dirname = plugin_configuration_dir(plugin_name)
         path = os.path.join(dirname, filename)
-        if os.path.isdir(dirname):
-            if os.path.isfile(path):
-                try:
-                    with open(path, 'r') as file:
-                        item = pickle.load(file)
-                        config.update(item)
-                except:
-                    pass
-        else:
-            os.makedirs(dirname)
+        try:
+            with open(path, 'rb') as file:
+                item = pickle.load(file)
+                config.update(item)
+        except Exception:
+            pass
         return config
 
-    def save_configuration_object(self, plugin_name, filename, item,
-                                  basedir=xdg_config_home):
-        dirname = os.path.join(basedir, 'gtg/plugins', plugin_name)
+    def save_configuration_object(self, plugin_name, filename, item):
+        dirname = plugin_configuration_dir(plugin_name)
+        if not os.path.isdir(dirname):
+            os.makedirs(dirname)
         path = os.path.join(dirname, filename)
         with open(path, 'wb') as file:
             pickle.dump(item, file)
