@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
 # Getting Things GNOME! - a personal organizer for the GNOME desktop
 # Copyright (c) 2008-2013 - Lionel Dricot & Bertrand Rousseau
@@ -20,14 +19,15 @@
 """
 A nice general purpose interface for the datastore and tagstore
 """
+import logging
+from gi.repository import GObject
 
-import gobject
+from GTG.core.tag import Tag, SEARCH_TAG_PREFIX
 
-from GTG.core.tag import Tag
-from GTG.tools.logger import Log
+log = logging.getLogger(__name__)
 
 
-class Requester(gobject.GObject):
+class Requester(GObject.GObject):
     """ A view on a GTG datastore.
 
     L{Requester} is a stateless object that simply provides a nice API for
@@ -36,15 +36,16 @@ class Requester(gobject.GObject):
     Multiple L{Requester}s can exist on the same datastore, so they should
     never have state of their own.
     """
+    __gsignals__ = {'status-changed': (GObject.SignalFlags.RUN_FIRST, None, (str, str, str,))}
 
     def __init__(self, datastore, global_conf):
         """Construct a L{Requester}."""
-        gobject.GObject.__init__(self)
+        super().__init__()
         self.ds = datastore
-        self.__config = global_conf
+        self._config = global_conf
         self.__basetree = self.ds.get_tasks_tree()
 
-    ############ Tasks Tree ######################
+    # Tasks Tree ######################
     # By default, we return the task tree of the main window
     def get_tasks_tree(self, name='active', refresh=True):
         return self.__basetree.get_viewtree(name=name, refresh=refresh)
@@ -58,20 +59,26 @@ class Requester(gobject.GObject):
     def get_basetree(self):
         return self.__basetree
 
-    # this method also update the viewcount of tags
     def apply_global_filter(self, tree, filtername):
+        """
+        This method also update the viewcount of tags
+        TODO(jakubbrindza): Evaluate if this is used somewhere before release
+        """
         tree.apply_filter(filtername)
         for t in self.get_all_tags():
             ta = self.get_tag(t)
             ta.apply_filter(filtername)
 
     def unapply_global_filter(self, tree, filtername):
+        """
+        TODO(jakubbrindza): Evaluate if this is used somewhere before release
+        """
         tree.unapply_filter(filtername)
         for t in self.get_all_tags():
             ta = self.get_tag(t)
             ta.unapply_filter(filtername)
 
-    ######### Filters bank #######################
+    # Filters bank #######################
     # List, by name, all available filters
     def list_filters(self):
         return self.__basetree.list_filters()
@@ -88,8 +95,7 @@ class Requester(gobject.GObject):
     def remove_filter(self, filter_name):
         return self.__basetree.remove_filter(filter_name)
 
-    ############## Tasks ##########################
-    ###############################################
+    # Tasks ##########################
     def has_task(self, tid):
         """Does the task 'tid' exist?"""
         return self.ds.has_task(tid)
@@ -135,7 +141,7 @@ class Requester(gobject.GObject):
         @param tid: The id of the task to be deleted.
         """
         # send the signal before actually deleting the task !
-        Log.debug("deleting task %s" % tid)
+        log.debug("deleting task %s", tid)
         return self.__basetree.del_node(tid, recursive=recursive)
 
     def get_task_id(self, task_title):
@@ -153,8 +159,7 @@ class Requester(gobject.GObject):
 
         return None
 
-    ############### Tags ##########################
-    ###############################################
+    # Tags ##########################
     def get_tag_tree(self):
         return self.ds.get_tagstore().get_viewtree(name='activetags')
 
@@ -168,17 +173,41 @@ class Requester(gobject.GObject):
         """
         return self.ds.new_tag(tagname)
 
-    def new_search_tag(self, name, query):
+    def new_search_tag(self, query):
         """
         Create a new search tag from search query
 
         Note: this modifies the datastore.
 
-        @param name:  name of the new search tag
         @param query: Query will be parsed using search parser
-        @return:      new tag
+        @return:      tag_id
         """
-        return self.ds.new_search_tag(name, query)
+        # ! at the beginning is reserved keyword for liblarch
+        if query.startswith('!'):
+            label = '_' + query
+        else:
+            label = query
+
+        # find possible name collisions
+        name, number = label, 1
+        already_search = False
+        while True:
+            tag = self.get_tag(SEARCH_TAG_PREFIX + name)
+            if tag is None:
+                break
+
+            if tag.is_search_tag() and tag.get_attribute("query") == query:
+                already_search = True
+                break
+
+            # this name is used, adding number
+            number += 1
+            name = label + ' ' + str(number)
+
+        if not already_search:
+            tag = self.ds.new_search_tag(name, query)
+
+        return SEARCH_TAG_PREFIX + name
 
     def remove_tag(self, name):
         """ calls datastore to remove a given tag """
@@ -198,7 +227,7 @@ class Requester(gobject.GObject):
         tagstore = self.ds.get_tagstore()
         view = tagstore.get_viewtree(name='tag_completion', refresh=False)
         tags = view.get_all_nodes()
-        tags.sort(cmp=lambda x, y: cmp(x.lower(), y.lower()))
+        tags.sort(key=str.lower)
         return tags
 
     def get_all_tags(self):
@@ -207,8 +236,14 @@ class Requester(gobject.GObject):
         """
         return self.ds.get_tagstore().get_main_view().get_all_nodes()
 
-    ############## Backends #######################
-    ###############################################
+    def delete_tag(self, tagname):
+        my_tag = self.get_tag(tagname)
+        for task_id in my_tag.get_related_tasks():
+            my_task = self.get_task(task_id)
+            my_task.remove_tag(tagname)
+            my_task.sync()
+
+    # Backends #######################
     def get_all_backends(self, disabled=False):
         return self.ds.get_all_backends(disabled)
 
@@ -230,16 +265,14 @@ class Requester(gobject.GObject):
     def backend_change_attached_tags(self, backend_id, tags):
         return self.ds.backend_change_attached_tags(backend_id, tags)
 
-    def save_datastore(self):
-        return self.ds.save()
+    def save_datastore(self, quit=False):
+        return self.ds.save(quit)
 
-    ############## Config ############################
-    ##################################################
-    def get_global_config(self):
-        return self.__config
+    # Config ############################
+    def get_config(self, system):
+        """ Returns configuration object for subsytem, e.g. browser """
+        return self._config.get_subconfig(system)
 
-    def get_config(self, name):
-        return self.__config.get_subconfig(name)
-
-    def save_config(self):
-        self.__config.save()
+    def get_task_config(self, task_id):
+        """ Returns configuration object for task """
+        return self._config.get_task_config(task_id)
