@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
 # Getting Things GNOME! - a personal organizer for the GNOME desktop
 # Copyright (c) 2008-2013 - Lionel Dricot & Bertrand Rousseau
@@ -24,10 +23,45 @@ Tagstore is to tag as datastore is to task. Of course, the tagstore is
 easier.  See the end of this file for the Tag object implementation.
 """
 
+import uuid
 import xml.sax.saxutils as saxutils
+import re
 
-from GTG.core import CoreConfig
 from liblarch import TreeNode
+from functools import reduce
+
+# Tags with special meaning
+ALLTASKS_TAG = "gtg-tags-all"
+NOTAG_TAG = "gtg-tags-none"
+SEP_TAG = "gtg-tags-sep"
+SEARCH_TAG = "search"
+
+SEARCH_TAG_PREFIX = "__SAVED_SEARCH_" # For name inside the tagtree
+
+def extract_tags_from_text(text):
+    """ Given a string, returns a list of the @tags contained in that """
+
+    return re.findall(r'(?:^|[\s])(@[\w\/\.\-\:\&]*\w)', text)
+
+
+def parse_tag_list(text):
+    """ Parse a line of a list of tasks. User can specify if the tag is
+    positive or not by prepending '!'.
+
+    @param  text:  string entry from user
+    @return: list of tupples (tag, is_positive)
+    """
+
+    result = []
+    for tag in text.split():
+        if tag.startswith('!'):
+            tag = tag[1:]
+            is_positive = False
+        else:
+            is_positive = True
+
+        result.append((tag, is_positive))
+    return result
 
 
 class Tag(TreeNode):
@@ -41,7 +75,7 @@ class Tag(TreeNode):
     for tags is C{name}, which always matches L{Tag.get_name()}.
     """
 
-    def __init__(self, name, req, attributes={}):
+    def __init__(self, name, req, attributes={}, tid=None):
         """Construct a tag.
 
         @param name: The name of the tag. Should be a string, generally
@@ -49,16 +83,21 @@ class Tag(TreeNode):
         @param attributes: Allow having initial set of attributes without
             calling _save callback
         """
-        TreeNode.__init__(self, name)
+        super().__init__(name)
         self._name = saxutils.unescape(str(name))
         self.req = req
         self._save = None
         self._attributes = {'name': self._name}
-        for key, value in attributes.iteritems():
+        for key, value in attributes.items():
             self.set_attribute(key, value)
 
         self.viewcount = None
 
+        if tid:
+            self.tid = tid
+        else:
+            self.tid = uuid.uuid4()
+
     def __get_viewcount(self):
         if not self.viewcount and self.get_name() != "gtg-tags-sep":
             basetree = self.req.get_basetree()
@@ -102,9 +141,16 @@ class Tag(TreeNode):
             TreeNode.add_child(self, child_id)
 
     def get_name(self):
-        """Return the name of the tag."""
+        """Return the internal name of the tag, as saved in the tree."""
         return self.get_attribute("name")
 
+    def get_friendly_name(self):
+        """Return the name of the tag, but without the internal search tag prefix."""
+        if self.is_search_tag():
+            return self.get_attribute("name")[len(SEARCH_TAG_PREFIX):]
+        else:
+            return self.get_attribute("name")
+
     def set_save_callback(self, save):
         self._save = save
 
@@ -119,14 +165,14 @@ class Tag(TreeNode):
         """
         modified = False
         if att_name == "name":
-            raise Set_Name_Attribute_Error(
+            raise KeyError(
                 "The name of tag cannot be set manually")
         elif att_name == "parent":
             self.add_parent(att_value)
             modified = True
         else:
             # Attributes should all be strings.
-            val = unicode(str(att_value), "UTF-8")
+            val = str(att_value)
             self._attributes[att_name] = val
             if self._save:
                 self._save()
@@ -145,7 +191,7 @@ class Tag(TreeNode):
             if self.has_parent():
                 parents_id = self.get_parents()
                 if len(parents_id) > 0:
-                    to_return = reduce(lambda a, b: "%s,%s" % (a, b),
+                    to_return = reduce(lambda a, b: f"{a},{b}",
                                        parents_id)
         elif att_name == 'label':
             to_return = self._attributes.get(att_name, self.get_id())
@@ -156,7 +202,7 @@ class Tag(TreeNode):
     def del_attribute(self, att_name):
         """Deletes the attribute C{att_name}.
         """
-        if not att_name in self._attributes:
+        if att_name not in self._attributes:
             return
         elif att_name in ['name', 'parent']:
             return
@@ -174,7 +220,7 @@ class Tag(TreeNode):
             names.
         @param withparent: If True, the "parent" attribute is attached
         """
-        attributes = self._attributes.keys()
+        attributes = list(self._attributes.keys())
         if butname:
             attributes.remove('name')
         if withparent:
@@ -183,7 +229,7 @@ class Tag(TreeNode):
                 attributes.append("parent")
         return attributes
 
-    ### TASK relation ####
+    # TASK relation ####
     def get_active_tasks_count(self):
         count = self.__get_count()
         return count
@@ -224,17 +270,11 @@ class Tag(TreeNode):
             my_task = self.req.get_task(task_id)
             my_task.modified()
 
-    # is it useful to keep the tag in the tagstore.
-    # if no attributes and no tasks, it is not useful.
-    def is_removable(self):
-        attr = self.get_all_attributes(butname=True, withparent=True)
-        return (len(attr) <= 0 and not self.is_used())
-
     def is_special(self):
         return bool(self.get_attribute('special'))
 
     def is_search_tag(self):
-        return CoreConfig.SEARCH_TAG in self.get_parents()
+        return SEARCH_TAG in self.get_parents()
 
     def is_used(self):
         return self.get_total_tasks_count() > 0
@@ -245,8 +285,3 @@ class Tag(TreeNode):
 
     def __str__(self):
         return "Tag: %s" % self.get_name()
-
-
-class Set_Name_Attribute_Error(Exception):
-    """Exception raised when try to set attribute to name"""
-    pass
