@@ -1,7 +1,6 @@
-# -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
-# Gettings Things Gnome! - a personal organizer for the GNOME desktop
-# Copyright (c) 2008-2012 - Lionel Dricot & Bertrand Rousseau
+# Getting Things GNOME! - a personal organizer for the GNOME desktop
+# Copyright (c) 2008-2013 - Lionel Dricot & Bertrand Rousseau
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -17,14 +16,14 @@
 # this program.  If not, see <http://www.gnu.org/licenses/>.
 # -----------------------------------------------------------------------------
 
-""" Configuration for browser, it contains path to .glade files """
+""" Configuration for browser, it contains path to .ui files """
 
 import os
 
 
-class ViewConfig:
+class ViewConfig():
     current_rep = os.path.dirname(os.path.abspath(__file__))
-    DELETE_GLADE_FILE = os.path.join(current_rep, "deletion.glade")
-    PREFERENCES_GLADE_FILE = os.path.join(current_rep, "preferences.glade")
-    PLUGINS_GLADE_FILE = os.path.join(current_rep, "plugins.glade")
-    BACKENDS_GLADE_FILE = os.path.join(current_rep, "backends_dialog.glade")
+    data = os.path.join(current_rep, 'data')
+    DELETE_UI_FILE = os.path.join(data, "deletion.ui")
+    PLUGINS_UI_FILE = os.path.join(data, "plugins.ui")
+    BACKENDS_UI_FILE = os.path.join(data, "backends.ui")
