@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
 # Getting Things GNOME! - a personal organizer for the GNOME desktop
 # Copyright (c) 2008-2013 - Lionel Dricot & Bertrand Rousseau
@@ -26,21 +25,19 @@ Also, it is supposed to handle more complex menus (with non-std widgets,
 like a color picker)
 """
 
-import pygtk
-pygtk.require('2.0')
-import gtk
+from gi.repository import Gtk
 
-from GTG import _
+from gettext import gettext as _
+from GTG.gtk.colors import generate_tag_color, color_add, color_remove
 
 
-class TagContextMenu(gtk.Menu):
+class TagContextMenu(Gtk.Menu):
     """Context menu fo the tag i the sidebar"""
 
-    def __init__(self, req, vmanager, tag=None):
-        self.__gobject_init__()
-        gtk.Menu.__init__(self)
+    def __init__(self, req, app, tag=None):
+        super().__init__()
         self.req = req
-        self.vmanager = vmanager
+        self.app = app
         self.tag = tag
         # Build up the menu
         self.set_tag(tag)
@@ -54,28 +51,48 @@ class TagContextMenu(gtk.Menu):
             i.destroy()
         if self.tag is not None:
             # Color chooser FIXME: SHOULD BECOME A COLOR PICKER
-            self.mi_cc = gtk.MenuItem()
-            self.mi_cc.set_label(_("Edit Tag..."))
+            self.mi_cc = Gtk.MenuItem()
+            self.mi_cc.set_label(_("Edit..."))
             self.append(self.mi_cc)
             self.mi_cc.connect('activate', self.on_mi_cc_activate)
+
+            self.mi_ctag = Gtk.MenuItem()
+            self.mi_ctag.set_label(_("Generate Color"))
+            self.append(self.mi_ctag)
+            self.mi_ctag.connect('activate', self.on_mi_ctag_activate)
+
             if self.tag.is_search_tag():
-                self.mi_del = gtk.MenuItem()
+                self.mi_del = Gtk.MenuItem()
                 self.mi_del.set_label(_("Delete"))
                 self.append(self.mi_del)
                 self.mi_del.connect('activate', self.on_mi_del_activate)
+            else:
+                self.mi_del_tag = Gtk.MenuItem()
+                self.mi_del_tag.set_label(_("Delete"))
+                self.append(self.mi_del_tag)
+                self.mi_del_tag.connect('activate', self.app.browser.on_delete_tag_activate)
+
         # Make it visible
         self.show_all()
 
-    ### PUBLIC API ############################################################
+    # PUBLIC API ##############################################################
     def set_tag(self, tag):
         """Update the context menu items using the tag attributes."""
         self.tag = tag
         self.__build_menu()
 
-    ### CALLBACKS #############################################################
+    # CALLBACKS ###############################################################
     def on_mi_cc_activate(self, widget):
         """Callback: show the tag editor upon request"""
-        self.vmanager.open_tag_editor(self.tag)
+        self.app.open_tag_editor(self.tag)
+
+    def on_mi_ctag_activate(self, widget):
+        random_color = generate_tag_color()
+        present_color = self.tag.get_attribute('color')
+        if present_color is not None:
+            color_remove(present_color)
+        self.tag.set_attribute('color', random_color)
+        color_add(random_color)
 
     def on_mi_del_activate(self, widget):
         """ delete a selected search """
