@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
 # Getting Things GNOME! - a personal organizer for the GNOME desktop
 # Copyright (c) 2008-2013 - Lionel Dricot & Bertrand Rousseau
@@ -21,25 +20,11 @@ The task editing GUI
 """
 import os
 
-from GTG import _
 
-
-class GnomeConfig:
+class GnomeConfig():
     current_rep = os.path.dirname(os.path.abspath(__file__))
-    GLADE_FILE = os.path.join(current_rep, "taskeditor.glade")
-
-    MARK_DONE = _("Mark as Done")
-    MARK_UNDONE = _("Mark as not Done")
-    MARK_DISMISS = _("Dismiss")
-    MARK_UNDISMISS = _("Undismiss")
-
-    MARK_DONE_TOOLTIP = _("Mark this task as done")
-    MARK_UNDONE_TOOLTIP = _("Mark this task as to be done")
-    MARK_DISMISS_TOOLTIP = _("Mark this task as not to be done anymore")
-    MARK_UNDISMISS_TOOLTIP = _("Mark this task as to be done")
-    DELETE_TOOLTIP = _("Permanently remove this task")
-    SUBTASK_TOOLTIP = _("Insert a subtask in this task")
-    TAG_TOOLTIP = _("Insert a tag in this task")
+    data = os.path.join(current_rep, "..", "data")
+    CALENDAR_UI_FILE = os.path.join(data, "calendar.ui")
 
     # Number of second between to save in the task editor
     SAVETIME = 7
