@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
 # Getting Things GNOME! - a personal organizer for the GNOME desktop
 # Copyright (c) 2008-2013 - Lionel Dricot & Bertrand Rousseau
@@ -17,15 +16,14 @@
 # this program.  If not, see <http://www.gnu.org/licenses/>.
 # -----------------------------------------------------------------------------
 
-""" Dialog for configuring plugins """
+""" Dialog for loading plugins """
 
-import gtk
-import pango
+from gi.repository import Gtk, Pango
 
-from GTG import _
-from GTG import info
+from GTG.core import info
 from GTG.core.plugins import GnomeConfig
 from GTG.core.plugins.engine import PluginEngine
+from gettext import gettext as _
 from GTG.gtk import ViewConfig
 
 # columns in PluginsDialog.plugin_store
@@ -36,16 +34,6 @@ PLUGINS_COL_SHORT_DESC = 3
 PLUGINS_COL_ACTIVATABLE = 4
 
 
-def plugin_icon(column, cell, store, iterator):
-    """ Callback to set the content of a PluginTree cell.
-
-    See PluginsDialog._init_plugin_tree().
-    """
-    cell.set_property('icon-name', 'gtg-plugin')
-    cell.set_property('sensitive',
-                      store.get_value(iterator, PLUGINS_COL_ACTIVATABLE))
-
-
 def plugin_error_short_text(plugin):
     """ Return small version of description of missing module dependencies
     for displaying in plugin markup """
@@ -60,7 +48,7 @@ def plugin_error_short_text(plugin):
     if modules:
         modules = "<small><b>%s</b></small>" % ', '.join(modules)
     if dbus:
-        ifaces = ["%s:%s" % (a, b) for (a, b) in dbus]
+        ifaces = [f"{a}:{b}" for (a, b) in dbus]
         dbus = "<small><b>%s</b></small>" % ', '.join(ifaces)
 
     # combine
@@ -82,7 +70,7 @@ def plugin_error_text(plugin):
         return GnomeConfig.CANLOAD
 
     # describe missing dependencies
-    text = "<b>%s</b>. \n" % GnomeConfig.CANNOTLOAD
+    text = f"<b>{GnomeConfig.CANNOTLOAD}</b>. \n"
     # get lists
     modules = plugin.missing_modules
     dbus = plugin.missing_dbus
@@ -91,7 +79,7 @@ def plugin_error_text(plugin):
     if modules:
         modules = "<small><b>%s</b></small>" % ', '.join(modules)
     if dbus:
-        ifaces = ["%s:%s" % (a, b) for (a, b) in dbus]
+        ifaces = [f"{a}:{b}" for (a, b) in dbus]
         dbus = "<small><b>%s</b></small>" % ', '.join(ifaces)
 
     # combine
@@ -120,91 +108,71 @@ def plugin_markup(column, cell, store, iterator, self):
     plugin = self.pengine.get_plugin(plugin_id)
     error_text = plugin_error_short_text(plugin)
     if error_text != "":
-        text = "<b>%s</b>\n%s\n<i>%s</i>" % (name, desc, error_text)
+        text = f"<b>{name}</b>\n{desc}\n<i>{error_text}</i>"
     else:
-        text = "<b>%s</b>\n%s" % (name, desc)
+        text = f"<b>{name}</b>\n{desc}"
 
     cell.set_property('markup', text)
     cell.set_property('sensitive',
                       store.get_value(iterator, PLUGINS_COL_ACTIVATABLE))
 
 
-class PluginsDialog:
+class PluginsDialog():
     """ Dialog for Plugins configuration """
 
-    def __init__(self, config_obj):
-        self.config_obj = config_obj
-        self.config = self.config_obj.get_subconfig("plugins")
-        builder = gtk.Builder()
-        builder.add_from_file(ViewConfig.PLUGINS_GLADE_FILE)
+    def __init__(self, requester):
+        self.req = requester
+        self.config = self.req.get_config("plugins")
+        builder = Gtk.Builder()
+
+        builder.add_from_file(ViewConfig.PLUGINS_UI_FILE)
 
         self.dialog = builder.get_object("PluginsDialog")
-        self.dialog.set_title(_("Plugins - %s" % info.NAME))
+        self.dialog.set_title(_("Plugins"))
         self.plugin_tree = builder.get_object("PluginTree")
         self.plugin_configure = builder.get_object("plugin_configure")
         self.plugin_about = builder.get_object("PluginAboutDialog")
         self.plugin_depends = builder.get_object('PluginDepends')
 
         self.pengine = PluginEngine()
-        # plugin config initiation
-        if self.pengine.get_plugins():
-            self.config.set("disabled",
-                [p.module_name for p in self.pengine.get_plugins("disabled")])
-            self.config.set("enabled",
-                [p.module_name for p in self.pengine.get_plugins("enabled")])
 
         # see constants PLUGINS_COL_* for column meanings
-        self.plugin_store = gtk.ListStore(str, bool, str, str, bool)
+        self.plugin_store = Gtk.ListStore(str, bool, str, str, bool)
 
         builder.connect_signals({
-                                'on_plugins_help':
-                                self.on_help,
-                                'on_plugins_close':
-                                self.on_close,
-                                'on_PluginsDialog_delete_event':
-                                self.on_close,
-                                'on_PluginTree_cursor_changed':
-                                self.on_plugin_select,
-                                'on_plugin_about':
-                                self.on_plugin_about,
-                                'on_plugin_configure':
-                                self.on_plugin_configure,
-                                'on_PluginAboutDialog_close':
-                                self.on_plugin_about_close,
+                                'on_PluginsDialog_delete_event': self.on_close,
+                                'on_PluginTree_cursor_changed': self.on_plugin_select,
+                                'on_plugin_about': self.on_plugin_about,
+                                'on_plugin_configure': self.on_plugin_configure,
+                                'on_PluginAboutDialog_close': self.on_plugin_about_close,
                                 })
 
     def _init_plugin_tree(self):
-        """ Initialize the PluginTree gtk.TreeView.
+        """ Initialize the PluginTree Gtk.TreeView.
 
         The format is modelled after the one used in gedit; see
         http://git.gnome.org/browse/gedit/tree/gedit/gedit-plugin-mapnager.c
         """
-        # force creation of the gtk.ListStore so we can reference it
+        # force creation of the Gtk.ListStore so we can reference it
         self._refresh_plugin_store()
 
         # renderer for the toggle column
-        renderer = gtk.CellRendererToggle()
+        renderer = Gtk.CellRendererToggle()
         renderer.set_property('xpad', 6)
         renderer.connect('toggled', self.on_plugin_toggle)
         # toggle column
-        column = gtk.TreeViewColumn(None, renderer, active=PLUGINS_COL_ENABLED,
+        column = Gtk.TreeViewColumn(None, renderer, active=PLUGINS_COL_ENABLED,
                                     activatable=PLUGINS_COL_ACTIVATABLE,
                                     sensitive=PLUGINS_COL_ACTIVATABLE)
         self.plugin_tree.append_column(column)
 
         # plugin name column
-        column = gtk.TreeViewColumn()
+        column = Gtk.TreeViewColumn()
         column.set_spacing(6)
-        # icon renderer for the plugin name column
-        icon_renderer = gtk.CellRendererPixbuf()
-        icon_renderer.set_property('stock-size', gtk.ICON_SIZE_SMALL_TOOLBAR)
-        icon_renderer.set_property('xpad', 3)
-        column.pack_start(icon_renderer, expand=False)
-        column.set_cell_data_func(icon_renderer, plugin_icon)
         # text renderer for the plugin name column
-        name_renderer = gtk.CellRendererText()
-        name_renderer.set_property('ellipsize', pango.ELLIPSIZE_END)
-        column.pack_start(name_renderer)
+        name_renderer = Gtk.CellRendererText()
+        name_renderer.set_property('ellipsize', Pango.EllipsizeMode.END)
+        column.pack_start(name_renderer, True)
         column.set_cell_data_func(name_renderer, plugin_markup, self)
 
         self.plugin_tree.append_column(column)
@@ -214,10 +182,10 @@ class PluginsDialog:
         self.plugin_tree.set_search_column(2)
 
     def _refresh_plugin_store(self):
-        """ Refresh status of plugins and put it in a gtk.ListStore """
+        """ Refresh status of plugins and put it in a Gtk.ListStore """
         self.plugin_store.clear()
         self.pengine.recheck_plugin_errors(True)
-        for name, plugin in self.pengine.plugins.iteritems():
+        for name, plugin in self.pengine.plugins.items():
             # activateable if there is no error
             self.plugin_store.append((name, plugin.enabled, plugin.full_name,
                                       plugin.short_description,
@@ -236,18 +204,12 @@ class PluginsDialog:
         self.dialog.hide()
         return True
 
-    @classmethod
-    def on_help(cls, widget):
-        """ In future, this will open help for plugins """
-        return True
-
     def on_plugin_toggle(self, widget, path):
         """Toggle a plugin enabled/disabled."""
         iterator = self.plugin_store.get_iter(path)
         plugin_id = self.plugin_store.get_value(iterator, PLUGINS_COL_ID)
         plugin = self.pengine.get_plugin(plugin_id)
-        plugin.enabled = not self.plugin_store.get_value(iterator,
-                                                         PLUGINS_COL_ENABLED)
+        plugin.enabled = not self.plugin_store.get_value(iterator, PLUGINS_COL_ENABLED)
         plugins_enabled = self.config.get("enabled")
         plugins_disabled = self.config.get("disabled")
         if plugin.enabled:
@@ -260,14 +222,12 @@ class PluginsDialog:
             plugins_disabled.append(plugin.module_name)
             if plugin.module_name in plugins_enabled:
                 plugins_enabled.remove(plugin.module_name)
+
         self.config.set("enabled", plugins_enabled)
         self.config.set("disabled", plugins_disabled)
-        self.plugin_store.set_value(iterator, PLUGINS_COL_ENABLED,
-                                    plugin.enabled)
+        self.plugin_store.set_value(iterator, PLUGINS_COL_ENABLED, plugin.enabled)
         self._update_plugin_configure(plugin)
 
-        self.config_obj.save()
-
     def on_plugin_select(self, plugin_tree):
         """ Callback when user select/unselect a plugin
 
@@ -300,7 +260,12 @@ class PluginsDialog:
         plugin_id = self.plugin_store.get_value(iterator, PLUGINS_COL_ID)
         plugin = self.pengine.get_plugin(plugin_id)
 
-        self.plugin_about.set_name(plugin.full_name)
+        # FIXME About plugin dialog looks much more different than
+        # it is in the current trunk
+        # FIXME repair it!
+        # FIXME Author is not usually set and is preserved from
+        # previous plugin... :/
+        self.plugin_about.set_program_name(plugin.full_name)
         self.plugin_about.set_version(plugin.version)
         authors = plugin.authors
         if isinstance(authors, str):
